<?php
/**
 * Helper functions related to customizer and options.
 *
 * @package Trade_Line
 */

if ( ! function_exists( 'trade_line_get_global_layout_options' ) ) :

	/**
	 * Returns global layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function trade_line_get_global_layout_options() {

		$choices = array(
			'left-sidebar'            => esc_html__( 'Primary Sidebar - Content', 'trade-line-pro' ),
			'right-sidebar'           => esc_html__( 'Content - Primary Sidebar', 'trade-line-pro' ),
			'three-columns'           => esc_html__( 'Three Columns ( Secondary - Content - Primary )', 'trade-line-pro' ),
			'three-columns-pcs'       => esc_html__( 'Three Columns ( Primary - Content - Secondary )', 'trade-line-pro' ),
			'three-columns-cps'       => esc_html__( 'Three Columns ( Content - Primary - Secondary )', 'trade-line-pro' ),
			'three-columns-psc'       => esc_html__( 'Three Columns ( Primary - Secondary - Content )', 'trade-line-pro' ),
			'three-columns-pcs-equal' => esc_html__( 'Three Columns ( Equal Primary - Content - Secondary )', 'trade-line-pro' ),
			'three-columns-scp-equal' => esc_html__( 'Three Columns ( Equal Secondary - Content - Primary )', 'trade-line-pro' ),
			'no-sidebar'              => esc_html__( 'No Sidebar', 'trade-line-pro' ),
		);
		$output = apply_filters( 'trade_line_filter_layout_options', $choices );
		return $output;

	}

endif;

if ( ! function_exists( 'trade_line_get_site_layout_options' ) ) :

	/**
	 * Returns site layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function trade_line_get_site_layout_options() {

		$choices = array(
			'fluid' => esc_html__( 'Fluid', 'trade-line-pro' ),
			'boxed' => esc_html__( 'Boxed', 'trade-line-pro' ),
		);
		$output = apply_filters( 'trade_line_filter_site_layout_options', $choices );
		if ( ! empty( $output ) ) {
			ksort( $output );
		}
		return $output;

	}

endif;

if ( ! function_exists( 'trade_line_get_pagination_type_options' ) ) :

	/**
	 * Returns pagination type options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function trade_line_get_pagination_type_options() {

		$choices = array(
			'default'               => esc_html__( 'Default (Older / Newer Post)', 'trade-line-pro' ),
			'numeric'               => esc_html__( 'Numeric', 'trade-line-pro' ),
			'infinite-scroll'       => esc_html__( 'Infinite Scroll - Scroll', 'trade-line-pro' ),
			'infinite-scroll-click' => esc_html__( 'Infinite Scroll - Click', 'trade-line-pro' ),
		);
		return $choices;

	}

endif;

if ( ! function_exists( 'trade_line_get_breadcrumb_type_options' ) ) :

	/**
	 * Returns breadcrumb type options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function trade_line_get_breadcrumb_type_options() {

		$choices = array(
			'disabled' => esc_html__( 'Disabled', 'trade-line-pro' ),
			'simple'   => esc_html__( 'Simple', 'trade-line-pro' ),
			'advanced' => esc_html__( 'Advanced', 'trade-line-pro' ),
		);
		return $choices;

	}

endif;


if ( ! function_exists( 'trade_line_get_archive_layout_options' ) ) :

	/**
	 * Returns archive layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function trade_line_get_archive_layout_options() {

		$choices = array(
			'full'    => esc_html__( 'Full Post', 'trade-line-pro' ),
			'excerpt' => esc_html__( 'Post Excerpt', 'trade-line-pro' ),
		);
		$output = apply_filters( 'trade_line_filter_archive_layout_options', $choices );
		if ( ! empty( $output ) ) {
			ksort( $output );
		}
		return $output;

	}

endif;

if ( ! function_exists( 'trade_line_get_image_sizes_options' ) ) :

	/**
	 * Returns image sizes options.
	 *
	 * @since 1.0.0
	 *
	 * @param bool  $add_disable True for adding No Image option.
	 * @param array $allowed Allowed image size options.
	 * @return array Image size options.
	 */
	function trade_line_get_image_sizes_options( $add_disable = true, $allowed = array(), $show_dimension = true ) {

		global $_wp_additional_image_sizes;
		$get_intermediate_image_sizes = get_intermediate_image_sizes();
		$choices = array();
		if ( true === $add_disable ) {
			$choices['disable'] = esc_html__( 'No Image', 'trade-line-pro' );
		}
		$choices['thumbnail'] = esc_html__( 'Thumbnail', 'trade-line-pro' );
		$choices['medium']    = esc_html__( 'Medium', 'trade-line-pro' );
		$choices['large']     = esc_html__( 'Large', 'trade-line-pro' );
		$choices['full']      = esc_html__( 'Full (original)', 'trade-line-pro' );

		if ( true === $show_dimension ) {
			foreach ( array( 'thumbnail', 'medium', 'large' ) as $key => $_size ) {
				$choices[ $_size ] = $choices[ $_size ] . ' (' . get_option( $_size . '_size_w' ) . 'x' . get_option( $_size . '_size_h' ) . ')';
			}
		}

		if ( ! empty( $_wp_additional_image_sizes ) && is_array( $_wp_additional_image_sizes ) ) {
			foreach ( $_wp_additional_image_sizes as $key => $size ) {
				$choices[ $key ] = $key;
				if ( true === $show_dimension ){
					$choices[ $key ] .= ' ('. $size['width'] . 'x' . $size['height'] . ')';
				}
			}
		}

		if ( ! empty( $allowed ) ) {
			foreach ( $choices as $key => $value ) {
				if ( ! in_array( $key, $allowed ) ) {
					unset( $choices[ $key ] );
				}
			}
		}

		return $choices;

	}

endif;


if ( ! function_exists( 'trade_line_get_image_alignment_options' ) ) :

	/**
	 * Returns image options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function trade_line_get_image_alignment_options() {

		$choices = array(
			'none'   => _x( 'None', 'Alignment', 'trade-line-pro' ),
			'left'   => _x( 'Left', 'Alignment', 'trade-line-pro' ),
			'center' => _x( 'Center', 'Alignment', 'trade-line-pro' ),
			'right'  => _x( 'Right', 'Alignment', 'trade-line-pro' ),
		);
		return $choices;

	}

endif;

if ( ! function_exists( 'trade_line_get_featured_slider_transition_effects' ) ) :

	/**
	 * Returns the featured slider transition effects.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function trade_line_get_featured_slider_transition_effects() {

		$choices = array(
			'fade'       => _x( 'fade', 'Transition Effect', 'trade-line-pro' ),
			'fadeout'    => _x( 'fadeout', 'Transition Effect', 'trade-line-pro' ),
			'none'       => _x( 'none', 'Transition Effect', 'trade-line-pro' ),
			'scrollHorz' => _x( 'scrollHorz', 'Transition Effect', 'trade-line-pro' ),
			'tileSlide'  => _x( 'tileSlide', 'Transition Effect', 'trade-line-pro' ),
			'tileBlind'  => _x( 'tileBlind', 'Transition Effect', 'trade-line-pro' ),
			'flipHorz'   => _x( 'flipHorz', 'Transition Effect', 'trade-line-pro' ),
			'flipVert'   => _x('flipVert','Transition Effect', 'trade-line-pro'),
			'shuffle'    => _x('shuffle','Transition Effect', 'trade-line-pro'),
		);
		$output = apply_filters( 'trade_line_filter_featured_slider_transition_effects', $choices );
		if ( ! empty( $output ) ) {
			ksort( $output );
		}
		return $output;

	}

endif;

if ( ! function_exists( 'trade_line_get_featured_slider_content_options' ) ) :

	/**
	 * Returns the featured slider content options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function trade_line_get_featured_slider_content_options() {

		$choices = array(
			'home-page'   => esc_html__( 'Home Page / Front Page', 'trade-line-pro' ),
			'entire-site' => esc_html__( 'Entire Site', 'trade-line-pro' ),
			'disabled'    => esc_html__( 'Disabled', 'trade-line-pro' ),
		);
		$output = apply_filters( 'trade_line_filter_featured_slider_content_options', $choices );
		if ( ! empty( $output ) ) {
			ksort( $output );
		}
		return $output;

	}

endif;

if ( ! function_exists( 'trade_line_get_featured_slider_type' ) ) :

	/**
	 * Returns the featured slider type.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function trade_line_get_featured_slider_type() {

		$choices = array(
			'featured-page'     => __( 'Featured Pages', 'trade-line-pro' ),
			'featured-category' => __( 'Featured Category', 'trade-line-pro' ),
			'featured-post'     => __( 'Featured Posts', 'trade-line-pro' ),
			'featured-image'    => __( 'Featured Images', 'trade-line-pro' ),
			'featured-tag'      => __( 'Featured Tag', 'trade-line-pro' ),
			'demo-slider'       => __( 'Demo Slider', 'trade-line-pro' ),
		);
		$output = apply_filters( 'trade_line_filter_featured_slider_type', $choices );
		if ( ! empty( $output ) ) {
			ksort( $output );
		}
		return $output;

	}

endif;

if ( ! function_exists( 'trade_line_get_featured_content_status_options' ) ) :

	/**
	 * Returns the featured content options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function trade_line_get_featured_content_status_options() {

		$choices = array(
			'home-page' => esc_html__( 'Home Page Only', 'trade-line-pro' ),
			'disabled'  => esc_html__( 'Disabled', 'trade-line-pro' ),
		);
		$output = apply_filters( 'trade_line_filter_featured_content_status_options', $choices );
		if ( ! empty( $output ) ) {
			ksort( $output );
		}
		return $output;

	}

endif;

if ( ! function_exists( 'trade_line_get_featured_content_type' ) ) :

	/**
	 * Returns the featured content type.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function trade_line_get_featured_content_type() {

		$choices = array(
			'featured-page' => esc_html__( 'Featured Pages', 'trade-line-pro' ),
			'featured-post' => esc_html__( 'Featured Posts', 'trade-line-pro' ),
			'demo-content'  => esc_html__( 'Demo Content', 'trade-line-pro' ),
		);
		$output = apply_filters( 'trade_line_filter_featured_content_type', $choices );
		if ( ! empty( $output ) ) {
			ksort( $output );
		}
		return $output;

	}

endif;

if( ! function_exists( 'trade_line_get_customizer_font_options' ) ) :

	/**
	 * Returns customizer font options.
	 *
	 * @since 1.0.0
	 */
	function trade_line_get_customizer_font_options(){

		$web_fonts = trade_line_get_web_fonts();
		$os_fonts  = trade_line_get_os_fonts();

		$web_fonts = array_merge( $web_fonts, $os_fonts );

		if ( ! empty( $web_fonts ) ) {
			ksort( $web_fonts );
		}

		$choices = array();

		if ( ! empty( $web_fonts ) ) {
			foreach ( $web_fonts as $k => $v ) {
				$choices[$k] = esc_html( $v['label'] );
			}
		}
		return $choices;

	}

endif;

if( ! function_exists( 'trade_line_get_web_fonts' ) ) :

	/**
	 * Returns web font options.
	 *
	 * @since 1.0.0
	 */
	function trade_line_get_web_fonts(){

		$choices = array(
			'philosopher' => array(
				'name'  => 'Philosopher',
				'label' => "'Philosopher', sans-serif",
				),
			'open-sans' => array(
				'name'  => 'Open Sans',
				'label' => "'Open Sans', sans-serif",
				),
			'pt-sans' => array(
				'name'  => 'PT Sans',
				'label' => "'PT Sans', sans-serif",
				),
			'merriweather-sans' => array(
				'name'  => 'Merriweather Sans',
				'label' => "'Merriweather Sans', sans-serif",
				),
			'roboto' => array(
				'name'  => 'Roboto',
				'label' => "'Roboto', sans-serif",
				),
			'arizonia' => array(
				'name'  => 'Arizonia',
				'label' => "'Arizonia', cursive",
				),
			'raleway' => array(
				'name'  => 'Raleway',
				'label' => "'Raleway', sans-serif",
				),
			'droid-sans' => array(
				'name'  => 'Droid Sans',
				'label' => "'Droid Sans', sans-serif",
				),
			'lato' => array(
				'name'  => 'Lato',
				'label' => "'Lato', sans-serif",
				),
			'dosis' => array(
				'name'  => 'Dosis',
				'label' => "'Dosis', sans-serif",
				),
			'slabo-27px' => array(
				'name'  => 'Slabo 27px',
				'label' => "'Slabo 27px', serif",
				),
			'oswald' => array(
				'name'  => 'Oswald',
				'label' => "'Oswald', sans-serif",
				),
			'pt-sans-narrow' => array(
				'name'  => 'PT Sans Narrow',
				'label' => "'PT Sans Narrow', sans-serif",
				),
			'josefin-slab' => array(
				'name'  => 'Josefin Slab',
				'label' => "'Josefin Slab', serif",
				),
			'alegreya' => array(
				'name'  => 'Alegreya',
				'label' => "'Alegreya', serif",
				),
			'exo' => array(
				'name'  => 'Exo',
				'label' => "'Exo', sans-serif",
				),
			'signika' => array(
				'name'  => 'Signika',
				'label' => "'Signika', sans-serif",
				),
			'lobster' => array(
				'name'  => 'Lobster',
				'label' => "'Lobster', cursive",
				),
			'indie-flower' => array(
				'name'  => 'Indie Flower',
				'label' => "'Indie Flower', cursive",
				),
			'shadows-into-light' => array(
				'name'  => 'Shadows Into Light',
				'label' => "'Shadows Into Light', cursive",
				),
			'kaushan-script' => array(
				'name'  => 'Kaushan Script',
				'label' => "'Kaushan Script', cursive",
				),
			'dancing-script' => array(
				'name'  => 'Dancing Script',
				'label' => "'Dancing Script', cursive",
				),
			'fredericka-the-great' => array(
				'name'  => 'Fredericka the Great',
				'label' => "'Fredericka the Great', cursive",
				),
			'covered-by-your-grace' => array(
				'name'  => 'Covered By Your Grace',
				'label' => "'Covered By Your Grace', cursive",
				),
			);
		$choices = apply_filters( 'trade_line_filter_web_fonts', $choices );

		if ( ! empty( $choices ) ) {
			ksort( $choices );
		}

		return $choices;

	}

endif;

if( ! function_exists( 'trade_line_get_os_fonts' ) ) :

	/**
	 * Returns OS font options.
	 *
	 * @since 1.0.0
	 */
	function trade_line_get_os_fonts(){

		$choices = array(
			'arial' => array(
				'name'  => 'Arial',
				'label' => "'Arial', sans-serif",
				),
			'georgia' => array(
				'name'  => 'Georgia',
				'label' => "'Georgia', serif",
				),
			'cambria' => array(
				'name'  => 'Cambria',
				'label' => "'Cambria', Georgia, serif",
				),
			'tahoma' => array(
				'name'  => 'Tahoma',
				'label' => "'Tahoma', Geneva, sans-serif",
				),
			'sans-serif' => array(
				'name'  => 'Sans Serif',
				'label' => "'Sans Serif', Arial",
				),
			'verdana' => array(
				'name'  => 'Verdana',
				'label' => "'Verdana', Geneva, sans-serif",
				),
			);
		$choices = apply_filters( 'trade_line_filter_os_fonts', $choices );

		if ( ! empty( $choices ) ) {
			ksort( $choices );
		}
		return $choices;

	}

endif;

if( ! function_exists( 'trade_line_get_font_family_from_key' ) ) :

	/**
	 * Return font family from font slug.
	 *
	 * @since 1.0.0
	 *
	 * @param string $key Font slug.
	 * @return string Font name.
	 */
	function trade_line_get_font_family_from_key( $key ){

		$output = '';

		$web_fonts = trade_line_get_web_fonts();
		$os_fonts  = trade_line_get_os_fonts();

		$fonts = array_merge( $web_fonts, $os_fonts );

		if ( isset( $fonts[ $key ] ) ) {
			$output = $fonts[ $key ]['label'];
		}
		return $output;

	}

endif;

if( ! function_exists( 'trade_line_get_font_family_theme_settings_options' ) ) :

	/**
	 * Returns font family theme settings options.
	 *
	 * @since 1.0.0
	 */
	function trade_line_get_font_family_theme_settings_options(){

		$choices = array(
			'font_site_title' => array(
				'label'   => __( 'Site Title', 'trade-line-pro' ),
				'default' => 'philosopher',
				),
			'font_site_tagline' => array(
				'label'   => __( 'Site Tagline', 'trade-line-pro' ),
				'default' => 'open-sans',
				),
			'font_site_default' => array(
				'label'   => __( 'Default', 'trade-line-pro' ),
				'default' => 'pt-sans',
				),

			'font_content_title' => array(
				'label'   => __( 'Content Title', 'trade-line-pro' ),
				'default' => 'open-sans',
				),
			'font_content_body' => array(
				'label'   => __( 'Content Body', 'trade-line-pro' ),
				'default' => 'open-sans',
				),
			'font_heading_tags' => array(
				'label'   => __( 'Heading Tags', 'trade-line-pro' ),
				'default' => 'open-sans',
				),
			'font_navigation' => array(
				'label'   => __( 'Navigation', 'trade-line-pro' ),
				'default' => 'open-sans',
				),
			);
		return $choices;

	}

endif;

if( ! function_exists( 'trade_line_get_default_colors' ) ) :

  /**
   * Returns default colors.
   *
   * @since 1.0.0
   *
   * @param string $scheme Color scheme.
   * @return array Color values based on scheme.
   */
	function trade_line_get_default_colors( $scheme = 'default' ){

		$output = array();

		switch ( $scheme ) {

			case 'default':
			default:
			$output = array(
				// Basic.
				'color_basic_background'              => '#ffffff',
				'color_basic_text'                    => '#686868',
				'color_basic_link'                    => '#2ba48c',
				'color_basic_link_hover'              => '#009a82',
				'color_basic_heading'                 => '#2ba48c',
				'color_basic_button_background'       => '#009a82',
				'color_basic_button_text'             => '#ffffff',
				'color_basic_button_background_hover' => '#009a82',
				'color_basic_button_text_hover'       => '#ffffff',

				// Header.
				'color_header_background'                     => '#ffffff',
				'color_header_title'                          => '#2ba48c',
				'color_header_title_hover'                    => '#009a82',
				'color_header_tagline'                        => '#666666',

				// Featured Content.
				'color_featured_content_background'       => '#ffffff',
				'color_featured_content_title_link'       => '#2ba48c',
				'color_featured_content_title_link_hover' => '#009a82',
				'color_featured_content_text'             => '#686868',

				// Content.
				'color_content_background'      => '#eeeeee',
				'color_content_title'           => '#2ba48c',
				'color_content_text'            => '#686868',
				'color_content_link'            => '#2ba48c',
				'color_content_link_hover'      => '#aaaaaa',
				'color_content_meta_link'       => '#2ba48c',
				'color_content_meta_link_hover' => '#009a82',
				'color_content_meta_icon'       => '#686868',

				// Sidebar.
				'color_sidebar_title'      => '#2ba48c',
				'color_sidebar_text'       => '#686868',
				'color_sidebar_link'       => '#2ba48c',
				'color_sidebar_link_hover' => '#009a82',
				'color_sidebar_list_icon'  => '#009a82',

				// Slider.
				'color_slider_title_background'      => '#2ba48c',
				'color_slider_text_background'       => '#dddddd',
				'color_slider_caption_text'          => '#686868',
				'color_slider_caption_link'          => '#ffffff',
				'color_slider_caption_link_hover'    => '#ffffff',
				'color_slider_icon'                  => '#ffffff',
				'color_slider_icon_hover'            => '#ffffff',
				'color_slider_icon_background'       => '#2ba48c',
				'color_slider_icon_background_hover' => '#009a82',
				'color_slider_pager'                 => '#ffffff',
				'color_slider_pager_active'          => '#2ba48c',

				// Home Page Widgets.
				'color_home_widgets_area_background'  => '#ffffff',
				'color_home_widgets_title'            => '#ffffff',
				'color_home_widgets_text'             => '#686868',
				'color_home_widgets_link'             => '#2ba48c',
				'color_home_widgets_link_hover'       => '#009a82',
				'color_home_widgets_title_background' =>'#2ba48c',

				// Primary Menu.
				'color_primary_menu_main_background'       => '#2ba48c',
				'color_primary_menu_link'                  => '#ffffff',
				'color_primary_menu_link_hover'            => '#ffffff',
				'color_primary_menu_link_background_hover' => '#009a82',

				// CTA Widget
				'color_cta_widget_background'              =>'#f9f9f9',
				'color_cta_widget_title'                   =>'#2ba48c',
				'color_cta_widget_text'                    =>'#686868',
				'color_cta_widget_border'                  =>'#2ba48c',
				'color_cta_widget_button_background_color' =>'#2ba48c',
				'color_cta_widget_button_color'            =>'#ffffff',
				'color_cta_widget_button_background_hover' =>'#009a82',
				'color_cta_widget_button_hover_color'      =>'#ffffff',

				// Widget Latest News
				'color_latest_news_main_widget_title'         =>'#ffffff',
				'color_latest_news_widget_title_background'   =>'#2ba48c',
				'color_latest_news_widget_title'              =>'#2ba48c',
				'color_latest_news_widget_title_hover'        =>'#009a82',
				'color_latest_news_widget_text'               =>'#686868',
				'color_latest_news_widget_link'               =>'#2ba48c',
				'color_latest_news_widget_link_hover'         =>'#009a82',
				'color_latest_news_widget_content_background' =>'#f9f9f9 ',
				'color_latest_news_widget_border'             =>'#2ba48c',

				// Portfolio Widget.
				'color_portfolio_main_widget_title'           => '#ffffff',
				'color_portfolio_widget_title_background'     => '#2ba48c',
				'color_portfolio_widget_title'                => '#ffffff',
				'color_portfolio_widget_tab'                  => '#686868',
				'color_portfolio_widget_tab_color_hover'      => '#009a82',
				'color_portfolio_widget_title_hover'          => '#009a82',

				// Widget Testimonial.
				'color_testimonial_main_widget_title'       => '#ffffff',
				'color_testimonial_widget_title_background' => '#2ba48c',
				'color_testimonial_widget_content'          => '#686868',
				'color_testimonial_widget_arrow'            => '#2ba48c',
				'color_testimonial_widget_arrow_hover'      => '#009a82',
				'color_testimonial_widget_author'           => '#2ba48c',
				'color_testimonial_pager'                   => '#aaaaaa',
				'color_testimonial_widget_pager_active'     => '#2ba48c',


				// Widget Team.
				'color_team_main_widget_title'               => '#ffffff',
				'color_team_widget_title_background'         => '#2ba48c',
				'color_team_widget_title'                    => '#ffffff',
				'color_team_widget_title_hover'              => '#2ba48c',
				'color_team_widget_sub_title'                => '#ffffff',
				'color_team_widget_title_background_color'   => '#2ba48c',
				'color_team_widget_content_text'             => '#ffffff',
				'color_team_widget_content_background_color' => '#000000',


				// Widget Service.
				'color_service_main_widget_title'            => '#ffffff',
				'color_service_widget_title_background'      => '#2ba48c',
				'color_service_widget_icon'                  => '#2ba48c',
				'color_service_widget_icon_background'       => '#e6ffff',
				'color_service_widget_title'                 => '#2ba48c',
				'color_service_widget_title_hover'           => '#2ba48c',
				'color_service_widget_text'                  => '#686868',
				'color_service_widget_link'                  => '#009a82',
				'color_service_widget_link_hover'            => '#2ba48c',
				'color_service_widget_item_hover_background' => '#009a82',

				// Footer Widgets.
				'color_footer_widgets_background' => '#333333',
				'color_footer_widgets_title'      => '#ffffff',
				'color_footer_widgets_text'       => '#bbbbbb',
				'color_footer_widgets_link'       => '#2ba48c',
				'color_footer_widgets_link_hover' => '#009a82',
				'color_footer_widgets_list_icon'  => '#2ba48c',

				// Footer area.
				'color_footer_area_background' => '#333333',
				'color_footer_area_text'       => '#ffffff',
				'color_footer_area_link'       => '#cccccc',
				'color_footer_area_link_hover' => '#ffffff',

				// Go To Top.
				'color_goto_top_icon'             => '#ffffff',
				'color_goto_top_icon_hover'       => '#ffffff',
				'color_goto_top_background'       => '#2ba48c',
				'color_goto_top_background_hover' => '#009a82',

				// Pagination.
				'color_pagination_link'                  => '#2ba48c ',
				'color_pagination_link_hover'            => '#ffffff',
				'color_pagination_link_background'       => '#ffffff',
				'color_pagination_link_background_hover' => '#2ba48c',

				// Breadcrumb.
				'color_breadcrumb_background' => '#ffffff',
				'color_breadcrumb_link'       => '#2ba48c',
				'color_breadcrumb_link_hover' => '#009a82',
				'color_breadcrumb_text'       => '#686868',

			);
			break;

		} // End switch.

	return $output;

	}

endif;


if( ! function_exists( 'trade_line_get_color_theme_settings_options' ) ) :

  /**
   * Returns color theme settings options.
   *
   * @since 1.0.0
   */
  function trade_line_get_color_theme_settings_options(){

  	$choices = array(

		// Basic.
  		'color_basic_background' => array(
  			'label'   => __( 'Background Color', 'trade-line-pro' ),
  			'section' => 'color_section_basic',
  			),
  		'color_basic_text' => array(
  			'label'   => __( 'Text Color', 'trade-line-pro' ),
  			'section' => 'color_section_basic',
  			),
  		'color_basic_link' => array(
  			'label'   => __( 'Link Color', 'trade-line-pro' ),
  			'section' => 'color_section_basic',
  			),
  		'color_basic_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'trade-line-pro' ),
  			'section' => 'color_section_basic',
  			),
  		'color_basic_heading' => array(
  			'label'   => __( 'Heading Color', 'trade-line-pro' ),
  			'section' => 'color_section_basic',
  			),
  		'color_basic_button_text' => array(
  			'label'   => __( 'Button Text Color', 'trade-line-pro' ),
  			'section' => 'color_section_basic',
  			),
  		'color_basic_button_background' => array(
  			'label'   => __( 'Button Background Color', 'trade-line-pro' ),
  			'section' => 'color_section_basic',
  			),
  		'color_basic_button_text_hover' => array(
  			'label'   => __( 'Button Text Hover Color', 'trade-line-pro' ),
  			'section' => 'color_section_basic',
  			),
  		'color_basic_button_background_hover' => array(
  			'label'   => __( 'Button Background Hover Color', 'trade-line-pro' ),
  			'section' => 'color_section_basic',
  			),

		// Header.
  		'color_header_background' => array(
  			'label'   => __( 'Background Color', 'trade-line-pro' ),
  			'section' => 'color_section_header',
  			),
  		'color_header_title' => array(
  			'label'   => __( 'Site Title Color', 'trade-line-pro' ),
  			'section' => 'color_section_header',
  			),
  		'color_header_title_hover' => array(
  			'label'   => __( 'Site Title Hover Color', 'trade-line-pro' ),
  			'section' => 'color_section_header',
  			),
  		'color_header_tagline' => array(
  			'label'   => __( 'Site Tagline Color', 'trade-line-pro' ),
  			'section' => 'color_section_header',
  			),

		// Primary Menu.
  		'color_primary_menu_main_background' => array(
  			'label'   => __( 'Main Background Color', 'trade-line-pro' ),
  			'section' => 'color_section_primary_menu',
  			),
  		'color_primary_menu_link' => array(
  			'label'   => __( 'Link Color', 'trade-line-pro' ),
  			'section' => 'color_section_primary_menu',
  			),
  		'color_primary_menu_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'trade-line-pro' ),
  			'section' => 'color_section_primary_menu',
  			),
  		'color_primary_menu_link_background_hover' => array(
  			'label'   => __( 'Link Background Hover Color', 'trade-line-pro' ),
  			'section' => 'color_section_primary_menu',
  			),

		// Featured Content.
  		'color_featured_content_background' => array(
  			'label'   => __( 'Background Color', 'trade-line-pro' ),
  			'section' => 'color_section_featured_content',
  			),
  		'color_featured_content_title_link' => array(
  			'label'   => __( 'Title Link Color', 'trade-line-pro' ),
  			'section' => 'color_section_featured_content',
  			),
  		'color_featured_content_title_link_hover' => array(
  			'label'   => __( 'Title Link Hover Color', 'trade-line-pro' ),
  			'section' => 'color_section_featured_content',
  			),
  		'color_featured_content_text' => array(
  			'label'   => __( 'Text Color', 'trade-line-pro' ),
  			'section' => 'color_section_featured_content',
  			),

		// Content.
  		'color_content_background' => array(
  			'label'   => __( 'Background Color', 'trade-line-pro' ),
  			'section' => 'color_section_content',
  			),
  		'color_content_title' => array(
  			'label'   => __( 'Title Color', 'trade-line-pro' ),
  			'section' => 'color_section_content',
  			),
  		'color_content_text' => array(
  			'label'   => __( 'Text Color', 'trade-line-pro' ),
  			'section' => 'color_section_content',
  			),
  		'color_content_link' => array(
  			'label'   => __( 'Link Color', 'trade-line-pro' ),
  			'section' => 'color_section_content',
  			),
  		'color_content_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'trade-line-pro' ),
  			'section' => 'color_section_content',
  			),
  		'color_content_meta_link' => array(
  			'label'   => __( 'Meta Link Color', 'trade-line-pro' ),
  			'section' => 'color_section_content',
  			),
  		'color_content_meta_link_hover' => array(
  			'label'   => __( 'Meta Link Hover Color', 'trade-line-pro' ),
  			'section' => 'color_section_content',
  			),
  		'color_content_meta_icon' => array(
  			'label'   => __( 'Meta Icon Color', 'trade-line-pro' ),
  			'section' => 'color_section_content',
  			),

		// Slider.
  		'color_slider_title_background' => array(
  			'label'   => __( 'Title Background Color', 'trade-line-pro' ),
  			'section' => 'color_section_slider',
  			),
  		'color_slider_text_background' => array(
  			'label'   => __( 'Text Background Color', 'trade-line-pro' ),
  			'section' => 'color_section_slider',
  			),
  		'color_slider_caption_text' => array(
  			'label'   => __( 'Caption Color', 'trade-line-pro' ),
  			'section' => 'color_section_slider',
  			),
  		'color_slider_caption_link' => array(
  			'label'   => __( 'Link Color', 'trade-line-pro' ),
  			'section' => 'color_section_slider',
  			),
  		'color_slider_caption_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'trade-line-pro' ),
  			'section' => 'color_section_slider',
  			),
  		'color_slider_icon' => array(
  			'label'   => __( 'Icon Color', 'trade-line-pro' ),
  			'section' => 'color_section_slider',
  			),
  		'color_slider_icon_hover' => array(
  			'label'   => __( 'Icon Hover Color', 'trade-line-pro' ),
  			'section' => 'color_section_slider',
  			),
  		'color_slider_icon_background' => array(
  			'label'   => __( 'Icon Background Color', 'trade-line-pro' ),
  			'section' => 'color_section_slider',
  			),
  		'color_slider_icon_background_hover' => array(
  			'label'   => __( 'Icon Background Hover Color', 'trade-line-pro' ),
  			'section' => 'color_section_slider',
  			),
  		'color_slider_pager' => array(
  			'label'   => __( 'Pager Color', 'trade-line-pro' ),
  			'section' => 'color_section_slider',
  			),
  		'color_slider_pager_active' => array(
  			'label'   => __( 'Pager Active Color', 'trade-line-pro' ),
  			'section' => 'color_section_slider',
  			),

		// Home Page Widgets.
  		'color_home_widgets_area_background' => array(
  			'label'   => __( 'Widget Area Background Color', 'trade-line-pro' ),
  			'section' => 'color_section_home_widgets',
  			),
  		'color_home_widgets_title' => array(
  			'label'   => __( 'Widget Title Color', 'trade-line-pro' ),
  			'section' => 'color_section_home_widgets',
  			),
  		'color_home_widgets_title_background' => array(
  			'label'   => __( 'Widget Title Background Color', 'trade-line-pro' ),
  			'section' => 'color_section_home_widgets',
  			),
  		'color_home_widgets_text' => array(
  			'label'   => __( 'Text Color', 'trade-line-pro' ),
  			'section' => 'color_section_home_widgets',
  			),
  		'color_home_widgets_link' => array(
  			'label'   => __( 'Link Color', 'trade-line-pro' ),
  			'section' => 'color_section_home_widgets',
  			),
  		'color_home_widgets_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'trade-line-pro' ),
  			'section' => 'color_section_home_widgets',
  			),

		// Sidebar.
  		'color_sidebar_title' => array(
  			'label'   => __( 'Title Color', 'trade-line-pro' ),
  			'section' => 'color_section_sidebar',
		),
  		'color_sidebar_text' => array(
  			'label'   => __( 'Text Color', 'trade-line-pro' ),
  			'section' => 'color_section_sidebar',
		),
  		'color_sidebar_link' => array(
  			'label'   => __( 'Link Color', 'trade-line-pro' ),
  			'section' => 'color_section_sidebar',
		),
  		'color_sidebar_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'trade-line-pro' ),
  			'section' => 'color_section_sidebar',
		),
  		'color_sidebar_list_icon' => array(
  			'label'   => __( 'List Icon Color', 'trade-line-pro' ),
  			'section' => 'color_section_sidebar',
		),

		// Footer area.
  		'color_footer_area_background' => array(
  			'label'   => __( 'Background Color', 'trade-line-pro' ),
  			'section' => 'color_section_footer_area',
  			),
  		'color_footer_area_text' => array(
  			'label'   => __( 'Text Color', 'trade-line-pro' ),
  			'section' => 'color_section_footer_area',
  			),
  		'color_footer_area_link' => array(
  			'label'   => __( 'Link Color', 'trade-line-pro' ),
  			'section' => 'color_section_footer_area',
  			),
  		'color_footer_area_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'trade-line-pro' ),
  			'section' => 'color_section_footer_area',
  			),

		// Go To Top.
  		'color_goto_top_icon' => array(
  			'label'   => __( 'Icon Color', 'trade-line-pro' ),
  			'section' => 'color_section_goto_top',
  			),
  		'color_goto_top_icon_hover' => array(
  			'label'   => __( 'Icon Hover Color', 'trade-line-pro' ),
  			'section' => 'color_section_goto_top',
  			),
  		'color_goto_top_background' => array(
  			'label'   => __( 'Background Color', 'trade-line-pro' ),
  			'section' => 'color_section_goto_top',
  			),
  		'color_goto_top_background_hover' => array(
  			'label'   => __( 'Background Hover Color', 'trade-line-pro' ),
  			'section' => 'color_section_goto_top',
  			),

		// Pagination.
  		'color_pagination_link' => array(
  			'label'   => __( 'Link Color', 'trade-line-pro' ),
  			'section' => 'color_section_pagination',
  			),
  		'color_pagination_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'trade-line-pro' ),
  			'section' => 'color_section_pagination',
  			),
  		'color_pagination_link_background' => array(
  			'label'   => __( 'Link Background Color', 'trade-line-pro' ),
  			'section' => 'color_section_pagination',
  			),
  		'color_pagination_link_background_hover' => array(
  			'label'   => __( 'Link Background Hover Color', 'trade-line-pro' ),
  			'section' => 'color_section_pagination',
  			),

		// Breadcrumb.
  		'color_breadcrumb_background' => array(
  			'label'   => __( 'Background Color', 'trade-line-pro' ),
  			'section' => 'color_section_breadcrumb',
  			),
  		'color_breadcrumb_link' => array(
  			'label'   => __( 'Link Color', 'trade-line-pro' ),
  			'section' => 'color_section_breadcrumb',
  			),
  		'color_breadcrumb_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'trade-line-pro' ),
  			'section' => 'color_section_breadcrumb',
  			),
  		'color_breadcrumb_text' => array(
  			'label'   => __( 'Text Color', 'trade-line-pro' ),
  			'section' => 'color_section_breadcrumb',
  			),

  		//Specific widget portfolio
  		'color_portfolio_main_widget_title' => array(
  			'label'   => __( 'Main Widget Title Color', 'trade-line-pro' ),
  			'section' => 'color_section_portfolio_widget',
  			),
  		'color_portfolio_widget_title_background' => array(
  			'label'   => __( 'Main Widget Title Background Color', 'trade-line-pro' ),
  			'section' => 'color_section_portfolio_widget',
  			),
  		'color_portfolio_widget_title' => array(
  			'label'   => __( 'Title Color', 'trade-line-pro' ),
  			'section' => 'color_section_portfolio_widget',
  			),
  		'color_portfolio_widget_title_hover' => array(
  			'label'   => __( 'Title Hover Color', 'trade-line-pro' ),
  			'section' => 'color_section_portfolio_widget',
  			),
  		'color_portfolio_widget_tab' => array(
  			'label'   => __( 'Tab Color', 'trade-line-pro' ),
  			'section' => 'color_section_portfolio_widget',
  			),
  		'color_portfolio_widget_tab_color_hover' => array(
  			'label'   => __( 'Tab Hover Color', 'trade-line-pro' ),
  			'section' => 'color_section_portfolio_widget',
  			),

  		//Specific widget testimonial
  		'color_testimonial_main_widget_title' => array(
  			'label'   => __( 'Main Widget Title Color', 'trade-line-pro' ),
  			'section' => 'color_section_testimonial_widget',
  			),
  		'color_testimonial_widget_title_background' => array(
  			'label'   => __( 'Main Widget Title Background Color', 'trade-line-pro' ),
  			'section' => 'color_section_testimonial_widget',
  			),
  		'color_testimonial_widget_content' => array(
  			'label'   => __( 'Content Color', 'trade-line-pro' ),
  			'section' => 'color_section_testimonial_widget',
  			),
  		'color_testimonial_widget_arrow' => array(
  			'label'   => __( 'Arrow Color', 'trade-line-pro' ),
  			'section' => 'color_section_testimonial_widget',
  			),
  		'color_testimonial_widget_arrow_hover' => array(
  			'label'   => __( 'Hover Arrow Color', 'trade-line-pro' ),
  			'section' => 'color_section_testimonial_widget',
  			),
  		'color_testimonial_widget_author' => array(
  			'label'   => __( 'Author Color', 'trade-line-pro' ),
  			'section' => 'color_section_testimonial_widget',
  			),
  		'color_testimonial_pager' => array(
  			'label'   => __( 'Pager Color', 'trade-line-pro' ),
  			'section' => 'color_section_testimonial_widget',
  			),
  		'color_testimonial_widget_pager_active' => array(
  			'label'   => __( 'Pager Active Color', 'trade-line-pro' ),
  			'section' => 'color_section_testimonial_widget',
  			),

  		//Specific widget service
  		'color_service_main_widget_title' => array(
  			'label'   => __( 'Main Widget Title Color', 'trade-line-pro' ),
  			'section' => 'color_section_service_widget',
  			),
  		'color_service_widget_title_background' => array(
  			'label'   => __( 'Main Widget Title Background Color', 'trade-line-pro' ),
  			'section' => 'color_section_service_widget',
  			),
  		'color_service_widget_icon' => array(
  			'label'   => __( 'Icon Color', 'trade-line-pro' ),
  			'section' => 'color_section_service_widget',
  			),
  		'color_service_widget_icon_background' => array(
  			'label'   => __( 'Icon Background Color', 'trade-line-pro' ),
  			'section' => 'color_section_service_widget',
  			),
  		'color_service_widget_title' => array(
  			'label'   => __( 'Tilte Color', 'trade-line-pro' ),
  			'section' => 'color_section_service_widget',
  			),
  		'color_service_widget_title_hover' => array(
  			'label'   => __( 'Tilte Hover Color', 'trade-line-pro' ),
  			'section' => 'color_section_service_widget',
  			),
  		'color_service_widget_text' => array(
  			'label'   => __( 'Text Color', 'trade-line-pro' ),
  			'section' => 'color_section_service_widget',
  			),
  		'color_service_widget_link' => array(
  			'label'   => __( 'Link Color', 'trade-line-pro' ),
  			'section' => 'color_section_service_widget',
  			),
  		'color_service_widget_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'trade-line-pro' ),
  			'section' => 'color_section_service_widget',
  			),
  		'color_service_widget_item_hover_background' => array(
  			'label'   => __( 'Item Hover Background Color', 'trade-line-pro' ),
  			'section' => 'color_section_service_widget',
  			),

  		//Specific widget CTA


  		'color_cta_widget_background' => array(
  			'label'   => __( 'Background Color', 'trade-line-pro' ),
  			'section' => 'color_section_cta_widget',
  			),
  		'color_cta_widget_title' => array(
  			'label'   => __( 'Title Color', 'trade-line-pro' ),
  			'section' => 'color_section_cta_widget',
  			),
  		'color_cta_widget_text' => array(
  			'label'   => __( 'Text Color', 'trade-line-pro' ),
  			'section' => 'color_section_cta_widget',
  			),
  		'color_cta_widget_border' => array(
  			'label'   => __( 'Border Color', 'trade-line-pro' ),
  			'section' => 'color_section_cta_widget',
  			),
  		'color_cta_widget_button_background_color' => array(
  			'label'   => __( 'Button Background Color', 'trade-line-pro' ),
  			'section' => 'color_section_cta_widget',
  			),
  		'color_cta_widget_button_color' => array(
  			'label'   => __( 'Button Color', 'trade-line-pro' ),
  			'section' => 'color_section_cta_widget',
  			),
  		'color_cta_widget_button_background_hover' => array(
  			'label'   => __( 'Button Background Hover Color', 'trade-line-pro' ),
  			'section' => 'color_section_cta_widget',
  			),
  		'color_cta_widget_button_hover_color' => array(
  			'label'   => __( 'Button Widget Color', 'trade-line-pro' ),
  			'section' => 'color_section_cta_widget',
  			),

  		//Specific widget Latest News

  		'color_latest_news_main_widget_title' => array(
  			'label'   => __( 'Main Widget Title Color', 'trade-line-pro' ),
  			'section' => 'color_section_latest_news_widget',
  			),
  		'color_latest_news_widget_title_background' => array(
  			'label'   => __( 'Main Widget Title Background Color', 'trade-line-pro' ),
  			'section' => 'color_section_latest_news_widget',
  			),
  		'color_latest_news_widget_title' => array(
  			'label'   => __( 'Title Color', 'trade-line-pro' ),
  			'section' => 'color_section_latest_news_widget',
  			),
  		'color_latest_news_widget_title_hover' => array(
  			'label'   => __( 'Title Hover', 'trade-line-pro' ),
  			'section' => 'color_section_latest_news_widget',
  			),

  		'color_latest_news_widget_text' => array(
  			'label'   => __( 'Text Color', 'trade-line-pro' ),
  			'section' => 'color_section_latest_news_widget',
  			),
  		'color_latest_news_widget_link' => array(
  			'label'   => __( 'Link Color', 'trade-line-pro' ),
  			'section' => 'color_section_latest_news_widget',
  			),
  		'color_latest_news_widget_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'trade-line-pro' ),
  			'section' => 'color_section_latest_news_widget',
  			),
  		'color_latest_news_widget_content_background' => array(
  			'label'   => __( 'Content Background Color', 'trade-line-pro' ),
  			'section' => 'color_section_latest_news_widget',
  			),
  		'color_latest_news_widget_border' => array(
  			'label'   => __( 'Border Color', 'trade-line-pro' ),
  			'section' => 'color_section_latest_news_widget',
  			),

  		//Specific widget team

  		'color_team_main_widget_title' => array(
  			'label'   => __( 'Main Widget Title Color', 'trade-line-pro' ),
  			'section' => 'color_section_team_widget',
  			),
  		'color_team_widget_title_background' => array(
  			'label'   => __( 'Main Widget Title Background Color', 'trade-line-pro' ),
  			'section' => 'color_section_team_widget',
  			),
  		'color_team_widget_title' => array(
  			'label'   => __( 'Title Color', 'trade-line-pro' ),
  			'section' => 'color_section_team_widget',
  			),
  		'color_team_widget_title_hover' => array(
  			'label'   => __( 'Title Hover Color', 'trade-line-pro' ),
  			'section' => 'color_section_team_widget',
  			),
  		'color_team_widget_sub_title' => array(
  			'label'   => __( 'Sub Title Color', 'trade-line-pro' ),
  			'section' => 'color_section_team_widget',
  			),
  		'color_team_widget_title_background_color' => array(
  			'label'   => __( 'Title Background Color', 'trade-line-pro' ),
  			'section' => 'color_section_team_widget',
  			),
  		'color_team_widget_content_text' => array(
  			'label'   => __( 'Content Text Color', 'trade-line-pro' ),
  			'section' => 'color_section_team_widget',
  			),
		'color_team_widget_content_background_color' => array(
			'label'   => __( 'Content Background Color', 'trade-line-pro' ),
			'section' => 'color_section_team_widget',
			),

		// Footer Widgets.
  		'color_footer_widgets_background' => array(
  			'label'   => __( 'Background Color', 'trade-line-pro' ),
  			'section' => 'color_section_footer_widgets',
  			),
  		'color_footer_widgets_title' => array(
  			'label'   => __( 'Title Color', 'trade-line-pro' ),
  			'section' => 'color_section_footer_widgets',
  			),
  		'color_footer_widgets_text' => array(
  			'label'   => __( 'Text Color', 'trade-line-pro' ),
  			'section' => 'color_section_footer_widgets',
  			),
  		'color_footer_widgets_link' => array(
  			'label'   => __( 'Link Color', 'trade-line-pro' ),
  			'section' => 'color_section_footer_widgets',
  			),
  		'color_footer_widgets_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'trade-line-pro' ),
  			'section' => 'color_section_footer_widgets',
  			),
  		'color_footer_widgets_list_icon' => array(
  			'label'   => __( 'List Icon Color', 'trade-line-pro' ),
  			'section' => 'color_section_footer_widgets',
  			),

  		);

    return $choices;

  }

endif;

if( ! function_exists( 'trade_line_get_color_sections_options' ) ) :

  /**
   * Returns color sections options.
   *
   * @since 1.0.0
   */
	function trade_line_get_color_sections_options(){

		$choices = array(
			'color_section_basic' => array(
				'label' => __( 'Basic Color Options', 'trade-line-pro' ),
				),
			'color_section_header' => array(
				'label' => __( 'Header Color Options', 'trade-line-pro' ),
				),
			'color_section_primary_menu' => array(
				'label' => __( 'Primary Menu Color Options', 'trade-line-pro' ),
				),
			'color_section_slider' => array(
				'label' => __( 'Slider Color Options', 'trade-line-pro' ),
				),
			'color_section_featured_content' => array(
				'label' => __( 'Featured Content Color Options', 'trade-line-pro' ),
				),
			'color_section_content' => array(
				'label' => __( 'Content Color Options', 'trade-line-pro' ),
				),
			'color_section_home_widgets' => array(
				'label' => __( 'Home Page Widgets Color Options', 'trade-line-pro' ),
				),
			'color_section_service_widget' => array(
				'label' => __( 'Service Widget Color Options', 'trade-line-pro' ),
				),
			'color_section_cta_widget' => array(
				'label' => __( 'CTA Widget Color Options', 'trade-line-pro' ),
				),
			'color_section_latest_news_widget' => array(
				'label' => __( 'Latest News Widget Color Options', 'trade-line-pro' ),
				),
			'color_section_portfolio_widget' => array(
				'label' => __( 'Portfolio Widget Color Options', 'trade-line-pro' ),
				),
			'color_section_testimonial_widget' => array(
				'label' => __( 'Testimonial Widget Color Options', 'trade-line-pro' ),
				),
			'color_section_team_widget' => array(
				'label' => __( 'Team Widget Color Options', 'trade-line-pro' ),
				),

			'color_section_sidebar' => array(
				'label' => __( 'Sidebar Color Options', 'trade-line-pro' ),
				),
			'color_section_breadcrumb' => array(
				'label' => __( 'Breadcrumb Color Options', 'trade-line-pro' ),
				),
			'color_section_goto_top' => array(
				'label' => __( 'Go To Top Color Options', 'trade-line-pro' ),
				),
			'color_section_pagination' => array(
				'label' => __( 'Pagination Color Options', 'trade-line-pro' ),
				),
			'color_section_footer_widgets' => array(
				'label' => __( 'Footer Widgets Color Options', 'trade-line-pro' ),
				),
			'color_section_footer_area' => array(
				'label' => __( 'Footer Area Color Options', 'trade-line-pro' ),
				),
			);
		return $choices;
	}

endif;

if ( ! function_exists( 'trade_line_get_featured_content_column_options' ) ) :

	/**
	 * Returns the featured content column.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function trade_line_get_featured_content_column_options() {

		$choices = array(
			'3' => sprintf( esc_html__( '%d Columns', 'trade-line-pro' ), 3 ),
			'4' => sprintf( esc_html__( '%d Columns', 'trade-line-pro' ), 4 ),
		);
		$output = apply_filters( 'trade_line_filter_featured_content_column_options', $choices );
		return $output;

	}

endif;


if( ! function_exists( 'trade_line_get_header_layout_options' ) ) :

  /**
   * Returns header layout options.
   *
   * @since 1.0.0
   */
  function trade_line_get_header_layout_options(){

    $choices = array(
      'layout-1' => get_template_directory_uri() . '/images/header-layout-1.png',
      'layout-2' => get_template_directory_uri() . '/images/header-layout-2.png',
    );
    return $choices;

  }

endif;

if ( ! function_exists( 'trade_line_get_featured_clients_content_options' ) ) :

	/**
	 * Returns the featured clients content options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function trade_line_get_featured_clients_content_options() {

		$choices = array(
			'home-page'   => esc_html__( 'Home Page / Front Page', 'trade-line-pro' ),
			'entire-site' => esc_html__( 'Entire Site', 'trade-line-pro' ),
			'disabled'    => esc_html__( 'Disabled', 'trade-line-pro' ),
		);
		$output = apply_filters( 'trade_line_filter_featured_clients_content_options', $choices );
		if ( ! empty( $output ) ) {
			ksort( $output );
		}
		return $output;

	}

endif;
